@@ -5,20 +5,12 @@ package App::Pinto;
 use strict;
 use warnings;
 
-use Encode;
 use Class::Load;
-use Term::Prompt;
-use List::Util qw(min);
-use Log::Dispatch::Screen;
-use Log::Dispatch::Screen::Color;
-
-use Pinto::Constants qw(:all);
-
 use App::Cmd::Setup -app;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_01'; # VERSION
+our $VERSION = '0.065_02'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -36,7 +28,6 @@ sub global_opt_spec {
 
 #------------------------------------------------------------------------------
 
-
 sub pinto {
     my ($self) = @_;
 
@@ -49,25 +40,10 @@ sub pinto {
         $global_options->{password} = $self->_prompt_for_password
             if defined $global_options->{password} and $global_options->{password} eq '-';
 
-        # Translating (progressive) verbose values into (regressive) log_level values.
-        # Note that we must not pass log_level into the constructor for Pinto, or it
-        # will set the logging level for its own internal logs.
-
-        my $logger_options = {};
-        $logger_options->{log_level} = 3 - min(delete $global_options->{verbose} || 0, 3);
-        $logger_options->{log_level} = 4 if delete $global_options->{quiet};
-        $logger_options->{no_color}  = 1 if delete $global_options->{no_color};
-
-        # TODO: Give helpful error message if the right backend
-        # is not installed.
-
         my $pinto_class = $self->pinto_class_for($global_options->{root});
         Class::Load::load_class($pinto_class);
 
-        my $pinto = $pinto_class->new( %{ $global_options } );
-        $pinto->add_logger($self->make_logger( %{ $logger_options } ));
-
-        $pinto;
+        $pinto_class->new( %{ $global_options } );
     };
 }
 
@@ -80,42 +56,12 @@ sub pinto_class_for {
 
 #------------------------------------------------------------------------------
 
-sub make_logger {
-    my ($self, %options) = @_;
-
-    my $no_color  = $options{no_color};
-    my $colors    = $no_color ? {} : ($self->log_colors);
-    my $log_class = 'Log::Dispatch::Screen';
-    $log_class   .= '::Color' unless $no_color;
-
-    my $log_level = $options{log_level};
-
-    return $log_class->new( min_level => $log_level,
-                            color     => $colors,
-                            stderr    => 1,
-                            newline   => 1 );
-}
-
-#------------------------------------------------------------------------------
-
-sub log_colors {
-    my ($self) = @_;
-
-    # TODO: Create command line options for controlling colors and
-    # process them here.
-
-    return $self->default_log_colors;
-}
-
-#------------------------------------------------------------------------------
-
-sub default_log_colors { return $PINTO_DEFAULT_LOG_COLORS }
-
-#------------------------------------------------------------------------------
-
 sub _prompt_for_password {
    my ($self) = @_;
 
+   require Encode;
+   require Term::Prompt;
+
    my $input    = Term::Prompt::prompt('p', 'Password:', '', '');
    my $password = Encode::decode_utf8($input);
    print "\n"; # Get on a new line
@@ -142,7 +88,7 @@ App::Pinto - Command-line driver for Pinto
 
 =head1 VERSION
 
-version 0.065_01
+version 0.065_02
 
 =head1 DESCRIPTION
 
@@ -155,21 +101,16 @@ host that is running L<pintod>, then install L<Pinto::Remote>.  If
 you're not sure what you need, then install L<Task::Pinto> to get the
 whole kit.
 
-=head1 METHODS
-
-=head2 pinto
-
-Returns a reference to a L<Pinto> or L<Pinto::Remote> object that has
-been constructed for this application.
-
 =head1 SEE ALSO
 
-L<Pinto::Manual> for general information on using Pinto.
-
 L<pinto> to create and manage a Pinto repository.
 
 L<pintod> to allow remote access to your Pinto repository.
 
+L<Pinto::Manual> for general information on using Pinto.
+
+L<Stratopan|http://stratopan.com> for hosting your Pinto repository in the cloud.
+
 =head1 SUPPORT
 
 =head2 Perldoc
